@@ -121,12 +121,15 @@ def create_xml_file(root_node_tag, output_file):
 
 # will add a node to a relative location
 def create_and_add_new_node(parent_node, node_tag, att_val_dict=None, node_text=None, namespace_map=None):
-    node_att_val_dict = {}
+    if att_val_dict is None:
+        att_val_dict = {}
     if att_val_dict is not None and namespace_map is not None:
+        node_att_val_dict = {}
         for key, val in att_val_dict.items():
             node_att_val_dict[_sanitize_att_name(key, namespace_map)] = val
+        att_val_dict = node_att_val_dict
 
-    node = etree.SubElement(parent_node, node_tag, node_att_val_dict)
+    node = etree.SubElement(parent_node, node_tag, att_val_dict)
     if node_text is not None:
         set_node_text(node, node_text)
     return node
